==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/GetBuildServiceBuildResultLogPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.GetBuildServiceBuildResultLogPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property buildName The name of the build resource.
 * @property buildResultName The name of the build result resource.
 * @property buildServiceName The name of the build service resource.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serviceName The name of the Service resource.
 */
public data class GetBuildServiceBuildResultLogPlainArgs(
    public val buildName: String,
    public val buildResultName: String,
    public val buildServiceName: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.GetBuildServiceBuildResultLogPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.GetBuildServiceBuildResultLogPlainArgs =
        com.pulumi.azurenative.appplatform.inputs.GetBuildServiceBuildResultLogPlainArgs.builder()
            .buildName(buildName.let({ args0 -> args0 }))
            .buildResultName(buildResultName.let({ args0 -> args0 }))
            .buildServiceName(buildServiceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetBuildServiceBuildResultLogPlainArgs].
 */
@PulumiTagMarker
public class GetBuildServiceBuildResultLogPlainArgsBuilder internal constructor() {
    private var buildName: String? = null

    private var buildResultName: String? = null

    private var buildServiceName: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value The name of the build resource.
     */
    @JvmName("ujalpxmtepshaccc")
    public suspend fun buildName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.buildName = mapped
    }

    /**
     * @param value The name of the build result resource.
     */
    @JvmName("ngsjscarwgvgcxbr")
    public suspend fun buildResultName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.buildResultName = mapped
    }

    /**
     * @param value The name of the build service resource.
     */
    @JvmName("ljcmkiyxwngorpvh")
    public suspend fun buildServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.buildServiceName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("hytqkpemgakispfu")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("bxfhavpbejcdlheb")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetBuildServiceBuildResultLogPlainArgs =
        GetBuildServiceBuildResultLogPlainArgs(
            buildName = buildName ?: throw PulumiNullFieldException("buildName"),
            buildResultName = buildResultName ?: throw PulumiNullFieldException("buildResultName"),
            buildServiceName = buildServiceName ?: throw PulumiNullFieldException("buildServiceName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/GetBuildServiceBuildResultLogPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.GetBuildServiceBuildResultLogPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property buildName The name of the build resource.
 * @property buildResultName The name of the build result resource.
 * @property buildServiceName The name of the build service resource.
 * @property resourceGroupName The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
 * @property serviceName The name of the Service resource.
 */
public data class GetBuildServiceBuildResultLogPlainArgs(
    public val buildName: String,
    public val buildResultName: String,
    public val buildServiceName: String,
    public val resourceGroupName: String,
    public val serviceName: String,
) :
    ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.GetBuildServiceBuildResultLogPlainArgs> {
    override fun toJava():
        com.pulumi.azurenative.appplatform.inputs.GetBuildServiceBuildResultLogPlainArgs =
        com.pulumi.azurenative.appplatform.inputs.GetBuildServiceBuildResultLogPlainArgs.builder()
            .buildName(buildName.let({ args0 -> args0 }))
            .buildResultName(buildResultName.let({ args0 -> args0 }))
            .buildServiceName(buildServiceName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .serviceName(serviceName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetBuildServiceBuildResultLogPlainArgs].
 */
@PulumiTagMarker
public class GetBuildServiceBuildResultLogPlainArgsBuilder internal constructor() {
    private var buildName: String? = null

    private var buildResultName: String? = null

    private var buildServiceName: String? = null

    private var resourceGroupName: String? = null

    private var serviceName: String? = null

    /**
     * @param value The name of the build resource.
     */
    @JvmName("gxyycldharedaikl")
    public suspend fun buildName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.buildName = mapped
    }

    /**
     * @param value The name of the build result resource.
     */
    @JvmName("jucajmmnmuhnnixo")
    public suspend fun buildResultName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.buildResultName = mapped
    }

    /**
     * @param value The name of the build service resource.
     */
    @JvmName("yvjtefhntgljutyh")
    public suspend fun buildServiceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.buildServiceName = mapped
    }

    /**
     * @param value The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.
     */
    @JvmName("xtsxbakptbcmtqhy")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the Service resource.
     */
    @JvmName("tvbcuwaxcxydffeg")
    public suspend fun serviceName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.serviceName = mapped
    }

    internal fun build(): GetBuildServiceBuildResultLogPlainArgs =
        GetBuildServiceBuildResultLogPlainArgs(
            buildName = buildName ?: throw PulumiNullFieldException("buildName"),
            buildResultName = buildResultName ?: throw PulumiNullFieldException("buildResultName"),
            buildServiceName = buildServiceName ?: throw PulumiNullFieldException("buildServiceName"),
            resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
            serviceName = serviceName ?: throw PulumiNullFieldException("serviceName"),
        )
}
